@@ -1,8 +1,8 @@
 # coding: utf-8
 
-VERSION = (0, 5, 6)
-CODENAME = "fuse jelly"
-BUILD_DT = (2020, 11, 29)
+VERSION = (0, 6, 0)
+CODENAME = "CHRISTMAAAAAS"
+BUILD_DT = (2020, 12, 1)
 
 S_VERSION = ".".join(map(str, VERSION))
 S_BUILD_DT = "{0:04d}-{1:02d}-{2:02d}".format(*BUILD_DT)
